Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Book ¶
type Book struct {
// i s b n
ISBN string `json:"isbn,omitempty"`
// author
Author string `json:"author,omitempty"`
// description
Description string `json:"description,omitempty"`
// title
Title string `json:"title,omitempty"`
}
Book book
swagger:model Book
func (*Book) ContextValidate ¶
ContextValidate validates this book based on context it is used
func (*Book) MarshalBinary ¶
MarshalBinary interface implementation
func (*Book) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type Error ¶
type Error struct {
// code
// Required: true
Code int64 `json:"code"`
// message
// Required: true
Message string `json:"message"`
}
Error error
swagger:model Error
func (*Error) ContextValidate ¶
ContextValidate validates this error based on context it is used
func (*Error) MarshalBinary ¶
MarshalBinary interface implementation
func (*Error) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type History ¶
type History struct {
// history
History []Status `json:"history"`
// isbn
Isbn string `json:"isbn,omitempty"`
}
History history
swagger:model History
func (*History) ContextValidate ¶
ContextValidate validate this history based on the context it is used
func (*History) MarshalBinary ¶
MarshalBinary interface implementation
func (*History) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type Status ¶
type Status struct {
// available
Available uint64 `json:"available,omitempty"`
// time
// Format: date-time
Time strfmt.DateTime `json:"time,omitempty"`
// type
Type StatusType `json:"type,omitempty"`
Unavailable uint64 `json:"unavailable,omitempty"`
}
Status status
swagger:model Status
func (*Status) ContextValidate ¶
ContextValidate validate this status based on the context it is used
func (*Status) MarshalBinary ¶
MarshalBinary interface implementation
func (*Status) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type StatusType ¶
type StatusType string
StatusType status type
swagger:model StatusType
const ( // StatusTypeAcquired captures enum value "acquired" StatusTypeAcquired StatusType = "acquired" // StatusTypeCheckin captures enum value "checkin" StatusTypeCheckin StatusType = "checkin" // StatusTypeCheckout captures enum value "checkout" StatusTypeCheckout StatusType = "checkout" )
func (StatusType) ContextValidate ¶
ContextValidate validates this status type based on context it is used